package de.ozgcloud.user;

import java.util.ArrayDeque;
import java.util.Deque;
import java.util.List;
import java.util.Objects;

import lombok.Builder;
import lombok.Getter;
import lombok.Singular;

@Builder
@Getter
class RoleHierarchy {

	private final String roleName;

	@Singular
	private List<RoleHierarchy> subRoles;

	public List<String> getFlattenedHierarchy(String roleName) {
		var subRoles = new ArrayDeque<String>();
		collectSubRoles(this, roleName, subRoles);
		return subRoles.stream().toList();
	}

	boolean collectSubRoles(RoleHierarchy role, String roleName, Deque<String> subRoles) {
		subRoles.addLast(role.getRoleName());
		if (Objects.equals(role.getRoleName(), roleName)) {
			return true;
		}
		for (var subRole : role.getSubRoles()) {
			if (collectSubRoles(subRole, roleName, subRoles)) {
				return true;
			}
		}
		subRoles.removeLast();
		return false;
	}

}
